GlobalSource

Enum GlobalSource 

pub enum GlobalSource {
    Normal,
    TraitDefault {
        trait_ref: TraitDeclRef,
        item_id: AssocConstId,
    },
    TraitImpl {
        impl_ref: TraitImplRef,
        trait_ref: TraitDeclRef,
        item_id: AssocConstId,
        reuses_default: bool,
    },
    VTableInstance {
        impl_ref: Option<TraitImplRef>,
    },
}
Where a given global came from.

Variants



Normal

A normal global.



TraitDefault

A default assoc const in a trait declaration.

Fields

trait_ref: TraitDeclRef

The trait declaration the const belongs to.

item_id: AssocConstId

The associated const this corresponds to.



TraitImpl

An associated const in a trait implementation.

Fields

impl_ref: TraitImplRef

The trait implementation the const belongs to.

trait_ref: TraitDeclRef

The trait declaration that the impl block implements.

item_id: AssocConstId

The associated const this corresponds to.

reuses_default: bool

True if the trait decl had a default value for this const and this item is a copy of the default item.



VTableInstance

Defines the vtable for a trait impl.

Fields

impl_ref: Option<TraitImplRef>

The originating impl. This is None in monomorphized mode: the vtable global itself identifies the concrete instantiation, so we don’t translate an impl reference solely to record its provenance.