pub struct GlobalDecl {
pub def_id: GlobalDeclId,
pub item_meta: ItemMeta,
pub generics: GenericParams,
pub ty: Ty,
pub size: Size,
pub align: Size,
pub ptr_metadata: Operand,
pub src: GlobalSource,
pub global_kind: GlobalKind,
pub value: ConstantExpr,
}Expand description
A global variable definition (constant or static).
Fields
def_id: GlobalDeclIditem_meta: ItemMetaThe meta data associated with the declaration.
generics: GenericParamsRemark: constants can actually have generic parameters.
struct V<const N: usize, T> {
x: [T; N],
}
impl<const N: usize, T> V<N, T> {
const LEN: usize = N; // This has generics <N, T>
}
fn use_v<const N: usize, T>(v: V<N, T>) {
let l = V::<N, T>::LEN; // We need to provided a substitution here
}ty: Tysize: SizeThe size in bytes of the global’s allocation.
align: SizeThe alignment in bytes of the global’s allocation.
ptr_metadata: OperandThe pointer metadata for references to this global (needed for unsized globals).
src: GlobalSourceThe context of the global: distinguishes normal items from trait-associated items and vtable instances.
global_kind: GlobalKindThe kind of global (static or const).
value: ConstantExprThe value of this constant/static. By default this is a ConstantExprKind::Call to the
initializer function that computes the value (the function uses the same generic parameters
as the global).
Implementations
Sourceimpl GlobalDecl
impl GlobalDecl
Sourcepub fn init_fun_id(&self) -> Option<FunDeclId>
pub fn init_fun_id(&self) -> Option<FunDeclId>
If this global’s value is a call to its initializer function, returns the initializer’s id.
Sourcepub fn is_unsafe_to_access(&self, _krate: &TranslatedCrate) -> bool
pub fn is_unsafe_to_access(&self, _krate: &TranslatedCrate) -> bool
Whether this global is unsafe to access, because it is a mutable or unsafe external static (safety.unsafe-static).
Sourcepub fn is_unsafe_to_declare(&self, _krate: &TranslatedCrate) -> bool
pub fn is_unsafe_to_declare(&self, _krate: &TranslatedCrate) -> bool
Whether this global is unsafe to declare.